<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt správce archivů&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Jednoduchý a na prostředí nezávislý nástroj pro správu archivů založený na Qt</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;https://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../about.ui" line="87"/>
        <source>Authors</source>
        <translation>Autoři</translation>
    </message>
    <message>
        <location filename="../about.ui" line="96"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programování:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Archivátor LXQt je odvozen od následujících aplikací:
* Engrampa z prostředí MATE
* File Roller z prostředí Gnome
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt správce archivů

Autorské právo © 2018 vývojáři LXQt

Tato aplikace je svobodný software, můžete ji šířit dále a/nebo
upravovat za podmínek GNU obecné veřejné licence
jak je vydaná nadací Free Software Foundation, buď verze 2
této licence, nebo (jako vaše volba) jakékoli pozdější.

Tato aplikace je šířena v naději, že bude užitečná,
ale BEZ JAKÝCHKOLI ZÁRUK, bez ani předpokládané záruky
PRODEJNOSTI nebo VHODNOSTI PRO KONKRÉTNÍ ÚČEL.
Podrobnosti naleznete v GNU obecné veřejné licenci.

Společně s touto aplikací byste měli obdržet kopii
GNU obecné veřejné licence, pokud tomu tak není, napište do nadace Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Tento typ archivu není podporován.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 soubory (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Všechny podporované formáty</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Příkaz se nepodařilo spustit.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Příkaz nenalezen.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Příkaz neskončil tak, jak měl.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Je vyžadováno heslo.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Chybějící svazek.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Chybná znaková sada.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Nepodporovaný formát souboru.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Došlo k neznámým chybám.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Rozdělit po svazcích o velikosti</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Šifrovat také seznam souborů</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Veškeré soubory (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>&amp;Rozbalit všechny soubory</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Vybali&amp;t označené soubory</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Akce</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Znovu vytvořit složky</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Přepsat existující soubory</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Nevybalovat soubory, které jsou starší než ty už přítomné</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>Veškeré soubory (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Archiver</source>
        <translation>Nástroj pro práci s archivy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Filter Files...</source>
        <translation>Filtrovat soubory…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>&amp;View</source>
        <translation>&amp;Pohled</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Main Toolbar</source>
        <translation>Hlavní lišta nástrojů</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;About</source>
        <translation>O &amp;aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>&amp;New</source>
        <translation>&amp;Nové</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>Save &amp;As</source>
        <translation>Uložit j&amp;ako</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>&amp;Extract</source>
        <translation>&amp;Rozbalit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>&amp;Test</source>
        <translation>O&amp;testovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>&amp;Properties</source>
        <translation>&amp;Vlastnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Cu&amp;t</source>
        <translation>Vyjmou&amp;t</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Rename</source>
        <translation>&amp;Přejmenovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Select All</source>
        <translation>&amp;Vybrat vše</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="328"/>
        <source>&amp;Find</source>
        <translation>&amp;Najít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="444"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>&amp;Add Files</source>
        <translation>Přid&amp;at soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Add F&amp;older</source>
        <translation>Přidat sl&amp;ožku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Pass&amp;word</source>
        <translation>&amp;Heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>&amp;Toolbar</source>
        <translation>Pruh nás&amp;trojů</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Stavový pruh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Strom složek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>S&amp;how as Folder</source>
        <translation>Zobrazit &amp;jako složku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="406"/>
        <source>Show &amp;All Files</source>
        <translation>Zobr&amp;azit veškeré soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <source>St&amp;op</source>
        <translation>Zas&amp;tavit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>&amp;Reload</source>
        <translation>&amp;Načíst znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Filename &amp;Encoding</source>
        <translation>&amp;Znaková sada názvu souboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Zobrazit označené položky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtrovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>&amp;Expand</source>
        <translation>&amp;Rozbalit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Dolů</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Sbalit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Nahoru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>All files (*)</source>
        <translation>Veškeré soubory (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Add only if &amp;newer</source>
        <translation>Přidat pouze pokud jsou &amp;novější</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Opravdu chcete označené soubory smazat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="672"/>
        <source>Version: %1</source>
        <translation>Verze: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>Success</source>
        <translation>Úspěšné</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>No errors have been found.</source>
        <translation>Nebyly nalezeny žádné chyby.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <location filename="../mainwindow.cpp" line="887"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="915"/>
        <source>N/A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>Uncompressed Size:</source>
        <translation>Nekomprimovaná velikost:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="921"/>
        <source>Compression Ratio:</source>
        <translation>Kompresní poměr:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>File Type</source>
        <translation>Typ souboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>File Size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="977"/>
        <source>Modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Encrypted</source>
        <translation>Šifrováno</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n soubor</numerusform>
            <numerusform>%n soubory</numerusform>
            <numerusform>%n souborů</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Zašifrovat seznam souborů</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Zobrazit heslo</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Pozn.:&lt;/b&gt; heslo bude použito pro zašifrování souborů které přidáte do stávajícího souboru a pro jejich následné rozšifrování. Při zavření archivu aplikace heslo zapomene.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Průběh</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="288"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar komprimovaný pomocí 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar zabalený pomocí bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar zabalený pomocí bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Komiksy komprimované pomocí rar (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Komiksy komprimované pomocí zip (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar zabalený pomocí gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Samorozbalovací zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar zabalený pomocí lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar zabalený pomocí lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar zabalený pomocí lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar zabalený pomocí lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Nekomprimovaný tar (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar zabalený pomocí (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar zabalený pomocí xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar zabalený pomocí zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Přidávání souboru: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="280"/>
        <source>Extracting file: </source>
        <translation>Vybalování souboru: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Odebírání souboru: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Mazání souborů z archivu</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Předělávání komprese archivu</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Rozbalování archivu</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Soubor nenalezen.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Tento typ archivu není podporován.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Archiv nenalezen</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Nemáte potřebná oprávnění.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Tento typ archivu není možné měnit</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Archiv není možné přidat sám do sebe.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Nedaří se najít svazek: %s</translation>
    </message>
</context>
</TS>
